showSemanticsDebugger property
Turns on a overlay that shows the accessibility information reported by the framework.
Implementation
final bool? showSemanticsDebugger;
Turns on a overlay that shows the accessibility information reported by the framework.
final bool? showSemanticsDebugger;